==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/lists/list-22.php <==
<?php
return array (
  'wso9rycamguchqpdwwvbad' => true,
  '0302multiblkjdcrbq0302' => true,
  'vd5ca6j9koqmzdueagoocj' => true,
  'twilighttennispenguins' => true,
  'thalesaugusto37027269*' => true,
  'smokymomichail19871007' => true,
  'sex.com77snnkesnakeman' => true,
  'mostafa@halo1203405600' => true,
  'jiueqqio0xst4gcirdnhk2' => true,
  'jefersonlindo123456789' => true,
  '4fwlvrixzmd7kmsyoxsr50' => true,
  '0535395515005353955150' => true,
  'zwezdablagininadiana18' => true,
  'zverev_7979zverev_7979' => true,
  'zs-dnxaybbshsmlcrvn-gg' => true,
  'zowhhhdmnqlapr78000000' => true,
  'zombieyeplaysminecraft' => true,
  'ziubxaf8alwaysvacant96' => true,
  'zhurahovskaya.klavdiya' => true,
  'zhannchik_chirchenkova' => true,
  'zhanna.pogorelovagusha' => true,
  'zhanelya_zhumagalievna' => true,
  'zhanara_turmahanbetova' => true,
  'zdoroviegeorgymarykety' => true,
  'zcfvfzghbdktrfntkmyfz8' => true,
  'zarina.abduvalikyzy.94' => true,
  'zarina0681809757galerr' => true,
  'zaremasboevasulemanova' => true,
  'zamotaoksanavictorivna' => true,
  'zaika.3452.omelchencko' => true,
  'zaharovvichzaharovvich' => true,
  'zadumskiy.rzadumskiy.r' => true,
  'yvafyvafvayyvafyvafvay' => true,
  'yuliya.kuzina.19901990' => true,
  'ytytutyuyuyytytutyuyuy' => true,
  'yourlifemeansnothing06' => true,
  'youmyhappinessmypain96' => true,
  'ymmijjames1906cleburne' => true,
  'yjdsqvjcrfktyrjujl;tyz' => true,
  'yishyellaokvikashshah7' => true,
  'yfnfkmrf_yfnfkmrf_1970' => true,
  'yeutaoditaokhongdoiqua' => true,
  'ybrjulfytepyftim442825' => true,
  'ybrbnfyfcnzybrbnfyfcnz' => true,
  'yasmimgalvao2225301412' => true,
  'yankeesvu4xq60_7lls0a5' => true,
  'yankeesuadhyaurrnp412m' => true,
  'yankeesthebest.cabelos' => true,
  'yankeesromantic4u90032' => true,
  'yankeesreadyforfunplay' => true,
  'yankeesrallyesport2000' => true,
  'yankeespussiestogether' => true,
  'yankeesoffthewahltoons' => true,
  'yankeesnortherntraders' => true,
  'yankeesmulinodellaglio' => true,
  'yankeesmathieubouchard' => true,
  'yankeesgav.maria.aleks' => true,
  'yankeesenjoy_thebestdj' => true,
  'yankeesdreamsofprelude' => true,
  'yankeesbachchusingh_95' => true,
  'yankeesamaracing032000' => true,
  'yamahar46jesuslittlebr' => true,
  'ya1504yasya11yaroslava' => true,
  'xxxxxxxxxxxxxxxxxxxxxx' => true,
  'xingfudfshelbyapeiffer' => true,
  'xdulsdul123xdulsdul123' => true,
  'x8b01zymn131423loveyou' => true,
  'x5service_ex5service_e' => true,
  'w.w.w.i1g2o3r4e5z6a7u8' => true,
  'wrfgdsfgdghdcfghdfhdfg' => true,
  'wordswortslobberhead77' => true,
  'wituhanoff@@@*password' => true,
  'wirtschaftsnachrichten' => true,
  'windows.programmer.vxd' => true,
  'windows.networking.ras' => true,
  'willow1soebadeb1760201' => true,
  'williamyenal.gogebakan' => true,
  'williamxxsweetshugarxx' => true,
  'williamwarnierfrederic' => true,
  'williamuniondrummer793' => true,
  'williamthouphepruthi80' => true,
  'williamtechnicalspring' => true,
  'williamsuper_magovskoe' => true,
  'williamsnegovik_kontra' => true,
  'williamsimon2016086.by' => true,
  'williamrobertterbetski' => true,
  'williamrichardfrance28' => true,
  'williamraphaeljohnlall' => true,
  'williamnils%5flennart.' => true,
  'williammichel.fredette' => true,
  'williamclazsic.boredum' => true,
  'williama9ob7z_9ur7ieg3' => true,
  'wildoneskeepsbanningme' => true,
  'whorenesslikabossaless' => true,
  'whitedoveandrunninbear' => true,
  'whenyoulookmeintheeyes' => true,
  'whateverybetetasudyqu9' => true,
  'whateverurtrturtjjfjfj' => true,
  'whateverthunderphucked' => true,
  'whateversunstrike54321' => true,
  'whateverstiffler2001ca' => true,
  'whateverservicesjoined' => true,
  'whateverpeterpertersen' => true,
  'whatevermelanie_wilkes' => true,
  'whateverkuntalbiswas99' => true,
  'whateverhotchick990051' => true,
  'whateverboneman-venus6' => true,
  'whateveravetisjannaira' => true,
  'wg1hlapohtgbcduogvlfyl' => true,
  'welcomezhan_bekzatovna' => true,
  'welcomewalter.knoepfli' => true,
  'welcomeunaibekov.eldar' => true,
  'welcomestonewall012000' => true,
  'welcomerichmondfamilia' => true,
  'welcomerailway__198888' => true,
  'welcomeplayersk8terdon' => true,
  'welcomepapichulo702009' => true,
  'welcomejlcarrascobrito' => true,
  'welcomejamesjburroughs' => true,
  'welcomejablomiehaywood' => true,
  'welcomegoloveshkin1988' => true,
  'welcomegeorgie.powells' => true,
  'welcomechicagobluesman' => true,
  'welcomebustthatcracker' => true,
  'welcomebcolewdswkbklbt' => true,
  'weihnachtsbaumna711509' => true,
  'wbnfltkmpkfxtndthj4444' => true,
  'waterresistayandanilov' => true,
  'wallflower-springsteen' => true,
  'wal1greenstsetia_marya' => true,
  'vyp.vaprvarvyp.vaprvar' => true,
  'vvalierchikvvalierchik' => true,
  'vsevokryggovno17071991' => true,
  'vsbudutsyavvsbudutsyav' => true,
  'vpn.internet.teslacoil' => true,
  'vovan27101976alexsandr' => true,
  'votpridurkiiditenah192' => true,
  'voorpraagmaarwordtdope' => true,
  'volodimir.makar.901990' => true,
  'vladludavmeste_na_veki' => true,
  'vladislavorlov06031985' => true,
  'vladislavbiluk06101996' => true,
  'vlad123456789123456789' => true,
  'vjzghtrhfcyfznjkcneirf' => true,
  'vjtujrjnbrfpdfkbevrf11' => true,
);

==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/lists/list-22.php <==
<?php
return array (
  'wso9rycamguchqpdwwvbad' => true,
  '0302multiblkjdcrbq0302' => true,
  'twilighttennispenguins' => true,
  'thalesaugusto37027269*' => true,
  'sex.com77snnkesnakeman' => true,
  'mostafa@halo1203405600' => true,
  'jefersonlindo123456789' => true,
  'jiueqqio0xst4gcirdnhk2' => true,
  'vd5ca6j9koqmzdueagoocj' => true,
  'smokymomichail19871007' => true,
  '4fwlvrixzmd7kmsyoxsr50' => true,
  '0535395515005353955150' => true,
  'zwezdablagininadiana18' => true,
  'zverev_7979zverev_7979' => true,
  'zs-dnxaybbshsmlcrvn-gg' => true,
  'zombieyeplaysminecraft' => true,
  'ziubxaf8alwaysvacant96' => true,
  'zhurahovskaya.klavdiya' => true,
  'zhannchik_chirchenkova' => true,
  'zhanna.pogorelovagusha' => true,
  'zhanelya_zhumagalievna' => true,
  'zhanara_turmahanbetova' => true,
  'zdoroviegeorgymarykety' => true,
  'zcfvfzghbdktrfntkmyfz8' => true,
  'zarina.abduvalikyzy.94' => true,
  'zaremasboevasulemanova' => true,
  'zaika.3452.omelchencko' => true,
  'zaharovvichzaharovvich' => true,
  'zadumskiy.rzadumskiy.r' => true,
  'yvafyvafvayyvafyvafvay' => true,
  'yuliya.kuzina.19901990' => true,
  'ytytutyuyuyytytutyuyuy' => true,
  'yourlifemeansnothing06' => true,
  'youmyhappinessmypain96' => true,
  'ymmijjames1906cleburne' => true,
  'yjdsqvjcrfktyrjujl;tyz' => true,
  'yishyellaokvikashshah7' => true,
  'yfnfkmrf_yfnfkmrf_1970' => true,
  'yeutaoditaokhongdoiqua' => true,
  'ybrjulfytepyftim442825' => true,
  'ybrbnfyfcnzybrbnfyfcnz' => true,
  'yasmimgalvao2225301412' => true,
  'yankeesvu4xq60_7lls0a5' => true,
  'yankeesuadhyaurrnp412m' => true,
  'yankeesthebest.cabelos' => true,
  'yankeesromantic4u90032' => true,
  'yankeesreadyforfunplay' => true,
  'yankeesrallyesport2000' => true,
  'yankeespussiestogether' => true,
  'yankeesoffthewahltoons' => true,
  'yankeesnortherntraders' => true,
  'yankeesmulinodellaglio' => true,
  'yankeesmathieubouchard' => true,
  'yankeesgav.maria.aleks' => true,
  'yankeesenjoy_thebestdj' => true,
  'yankeesamaracing032000' => true,
  'yankeesdreamsofprelude' => true,
  'yankeesbachchusingh_95' => true,
  'yamahar46jesuslittlebr' => true,
  'ya1504yasya11yaroslava' => true,
  'xxxxxxxxxxxxxxxxxxxxxx' => true,
  'xingfudfshelbyapeiffer' => true,
  'xdulsdul123xdulsdul123' => true,
  'x5service_ex5service_e' => true,
  'wrfgdsfgdghdcfghdfhdfg' => true,
  'wordswortslobberhead77' => true,
  'wituhanoff@@@*password' => true,
  'wirtschaftsnachrichten' => true,
  'windows.programmer.vxd' => true,
  'windows.networking.ras' => true,
  'willow1soebadeb1760201' => true,
  'williamyenal.gogebakan' => true,
  'williamxxsweetshugarxx' => true,
  'williamwarnierfrederic' => true,
  'williamuniondrummer793' => true,
  'williamthouphepruthi80' => true,
  'williamtechnicalspring' => true,
  'williamsuper_magovskoe' => true,
  'williamsnegovik_kontra' => true,
  'williamsimon2016086.by' => true,
  'williamrobertterbetski' => true,
  'williamrichardfrance28' => true,
  'williamraphaeljohnlall' => true,
  'williamnils%5flennart.' => true,
  'williammichel.fredette' => true,
  'williamclazsic.boredum' => true,
  'williama9ob7z_9ur7ieg3' => true,
  'wildoneskeepsbanningme' => true,
  'whitedoveandrunninbear' => true,
  'whenyoulookmeintheeyes' => true,
  'whateverybetetasudyqu9' => true,
  'whateverurtrturtjjfjfj' => true,
  'whateverthunderphucked' => true,
  'whateversunstrike54321' => true,
  'whateverstiffler2001ca' => true,
  'whateverservicesjoined' => true,
  'whateverpeterpertersen' => true,
  'whatevermelanie_wilkes' => true,
  'whateverkuntalbiswas99' => true,
  'whateverhotchick990051' => true,
  'whateveravetisjannaira' => true,
  'whateverboneman-venus6' => true,
  'welcomezhan_bekzatovna' => true,
  'welcomewalter.knoepfli' => true,
  'welcomeunaibekov.eldar' => true,
  'welcomestonewall012000' => true,
  'welcomerailway__198888' => true,
  'welcomeplayersk8terdon' => true,
  'welcomepapichulo702009' => true,
  'welcomejlcarrascobrito' => true,
  'welcomejamesjburroughs' => true,
  'welcomejablomiehaywood' => true,
  'welcomegoloveshkin1988' => true,
  'welcomegeorgie.powells' => true,
  'welcomechicagobluesman' => true,
  'welcomebustthatcracker' => true,
  'welcomebcolewdswkbklbt' => true,
  'welcomerichmondfamilia' => true,
  'wbnfltkmpkfxtndthj4444' => true,
  'waterresistayandanilov' => true,
  'wal1greenstsetia_marya' => true,
  'w.w.w.i1g2o3r4e5z6a7u8' => true,
  'vyp.vaprvarvyp.vaprvar' => true,
  'vvalierchikvvalierchik' => true,
  'vsevokryggovno17071991' => true,
  'vsbudutsyavvsbudutsyav' => true,
  'vpn.internet.teslacoil' => true,
  'vovan27101976alexsandr' => true,
  'votpridurkiiditenah192' => true,
  'voorpraagmaarwordtdope' => true,
  'volodimir.makar.901990' => true,
  'vladislavorlov06031985' => true,
  'vladislavbiluk06101996' => true,
  'vlad123456789123456789' => true,
  'vjzghtrhfcyfznjkcneirf' => true,
  'vjtujrjnbrfpdfkbevrf11' => true,
  'vitalij.burmistrov1981' => true,
  'vip.zilvovavip.zilvova' => true,
  'vip.lyumennvip.lyumenn' => true,
  'vinicius01111994leitte' => true,
  'viktorijagenja10072010' => true,
  'viktor2012nv3artsumgun' => true,
  'vfvjxrfnscegthrkfccyfz' => true,
  'vfrcbvitdxtyrj03031947' => true,
  'vfrc8800hdbynthytn4330' => true,
  'vfhbyf100682vfvf280760' => true,
  'vfdcxsaz123vfdcxsaz123' => true,
  'vervevevervverveveverv' => true,
  'veronikaveronikasvo777' => true,
  'vepsrfvjzghtrhfcyf1990' => true,
  'vasia123eeevasia123eee' => true,
  'vapvp.vpvapvapvp.vpvap' => true,
  'van9petkin8van9petkin8' => true,
  'valsova1992valsova1992' => true,
  'valerman4ik89500357290' => true,
  'vader199816lee12vlol45' => true,
);
